#!/usr/bin/env python

class FStealerExploit:
	def initialize(self, target):
		raise Exception("Implement in inherited class.")

	def getFile(self, path):
		raise Exception("Implement in inherited class.")

class LocalStealerExploit(FStealerExploit):
	def initialize(self, target):
		pass

	def getFile(self, path):
		print "Getting file: %s"%path
		try:
			return open(path,"r").read()
		except IOError:
			return None
