#!/bin/sh
echo "Creating /etc/fstealer"
sudo mkdir -p /etc/fstealer
echo "Copying blacklist"
sudo cp blacklist /etc/fstealer/
echo "Copying pathlist"
sudo cp pathlist /etc/fstealer/
echo "Copying module specific data"
sudo cp -r moddata /etc/fstealer/
echo "Installing main program"
sudo cp fstealer.py /usr/local/bin/fstealer
echo "Installing python library"
sudo cp -r libfstealer /usr/lib/python2.7/
echo "done"
