#!/usr/bin/env python

import re
import os
from module import FStealerModule

class ProcModule(FStealerModule):
	def initialize(self):
		f = self.openModuleFile("signatures","r")
		self.apachesubpaths = []
		for line in f:
			self.apachesubpaths.append(line.strip())
		for subpath in self.apachesubpaths:
			self.addPath(os.path.join("/proc", subpath))

module = ProcModule
